#
# spec file for package ghc-http-api-data
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-api-data
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4
Release:        1.4
Summary:        Converting to/from HTTP API data like URL pieces, headers and query parameters
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-iso8601-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cabal-doctest-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-locale-compat-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-uuid-types-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-nats-devel
BuildRequires:  ghc-quickcheck-instances-devel
%endif

%description
This package defines typeclasses used for converting Haskell data types to and
from HTTP API data.

Please see README.md.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed Nov 14 2018 psimons@suse.com
- Update http-api-data to version 0.4.
  0.4
  - --
  * `NominalDiffTime` instances preserve precision (roundtrip)
  * Add `Semigroup.Min`, `Max`, `First`, `Last` instances
  * Add `Tagged b a` instances
* Wed Oct 10 2018 psimons@suse.com
- Update http-api-data to version 0.3.10.
  0.3.10
  - --
  * Fix 'SetCookie' instances
    (see [#86](https://github.com/fizruk/http-api-data/pull/86))
  * Add support for `Fixed`
    (see [#78](https://github.com/fizruk/http-api-data/pull/87))
  0.3.9
  - --
  * GHC-8.6 support
  * Remove dependency on `uri-bytestring` and use functions from `http-types` instead
    (see [#75](https://github.com/fizruk/http-api-data/pull/78))
  * Add support for `SetCookie`
    (see [#74](https://github.com/fizruk/http-api-data/pull/74))
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update http-api-data to version 0.3.8.1.
  * GHC-8.4.1 support
  * Stable URL-encoding for `Form`s (see [#67](https://github.com/fizruk/http-api-data/pull/67)):
  * Introduce `urlEncodeParams` and `urlDecodeParams`;
  * Introduce `urlEncodeAsFormStable` and use stable encoding for doctests;
  * Add `toEntriesByKeyStable` and `toListStable`;
  * Add `Semigroup` instance for `Form` (see [#69](https://github.com/fizruk/http-api-data/pull/69));
  * Relax upper bound on Cabal (see [#73](https://github.com/fizruk/http-api-data/pull/73)).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu May 18 2017 psimons@suse.com
- Update to version 0.3.7.1 with cabal2obs.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 0.3.7 with cabal2obs.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.3.6 with cabal2obs.
* Fri Mar 31 2017 psimons@suse.com
- Improve package description.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.3.5 with cabal2obs.
* Mon Jul 25 2016 psimons@suse.com
- Update to version 0.2.4 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.3 revision 0 with cabal2obs.
* Sat Jun 11 2016 mimi.vx@gmail.com
- update to 0.2.3
  * Add more parser helpers for Bounded Enum types.
* Sun Dec 13 2015 mimi.vx@gmail.com
- update to 0.2.2
  * Add instances for more time types: LocalTime, ZonedTime, UTCTime and NominalDiffTime
* Mon Nov 23 2015 mimi.vx@gmail.com
- correct license to BSD-2-Clause
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
